==> ulyxex.1.4.8.alone.zip: pages/core/admin_site.php <==
<?php
/* Ulyxex version 1.4.8 *****************/
class AdminSite extends Admin {
	function __construct(){
		$this->h = New Html();
		$this->t = New Translate();
	}
	public function site_params(){
		$h = $this->h;$t = $this->t;
		if ($_SESSION['userid'] == 1){
			$query = 	SELECT.
							PARAMS.".*,".PAGES.".NAME".
						FROM.
							PARAMS.
							INNERJOIN.PAGES._ON_.PAGES.".ID = ".PARAMS.".PAGEID";
						WHERE.
							PARAMS.".ID = 1"._AND_.PAGES.".ID = ".PARAMS.".PAGEID";
			$query = $this->q($query);
			$dat = $this->fetch($query);
			$_[] = $h->input("hidden","update",1);
			$_[] = $h->p($t->wr("page name in use for home is").$h->b("\"".$dat['NAME']."\""));
			$options = array("tree"=>"tree","line"=>"line","child"=>"child");
			$_[] = $h->p($t->wr("navigation").$h->select($options,"navtype",$dat['NAVTYPE']));
			$_[] = $h->p($t->wr("select home page").$this->list_pages_select($dat['PAGEID'],"pageId"));
			$_[] = $h->p($t->wr("type").$h->input("text","type",$dat['TYPEPAGE'],"readonly='readonly' style='border:none;font-weight:bold'")." &#38;(".$t->w("param").") ".$h->input("text","param",$dat['PAGEID'],"readonly='readonly' style='border:none;font-weight:bold'"));
			$_[] = $h->p($t->wr("main css").$h->input("text","css",$dat['CSS'],"size='50'"));
			$_[] = $h->p($t->wr("articles by page").$h->input("text","articlespage",$dat['ARTICLESPAGE'],"size='4'"));
			$_[] = $h->p("------------------");
			$_[] = $h->p($t->wr("items by page admin").$h->input("text","items",$dat['ITEMS'],"size='4'"));
			$_[] = $h->p($t->wr("website administrator mail").$h->input("text","mail",$dat['MAIL']));
			$_[] = $h->p($h->input("submit","save",$t->w("update all")));
			$inputs = implode("",$_);
			return $h->form($inputs,"home","post","admin.php?action=admin_home");
		}
	}
	public function update_site_params(){
		$vals = explode("&",$_POST['pageId']);
		$typePage = explode("=",$vals[0])[1];
		$paramId = explode("=",$vals[1])[1];
		$query = UPDATE.PARAMS.
					SET."PAGEID = '".$this->h->word($paramId).
					"',TYPEPAGE = '".$this->h->word($typePage).
					"',NAVTYPE = '".$this->h->word($_POST['navtype']).
					"',CSS = '".$this->h->word($_POST['css']).
					"',ARTICLESPAGE = '".$this->h->num($_POST['articlespage']).
					"',ITEMS = '".$this->h->num($_POST['items']).
					"',MAIL = '".$this->h->safe($_POST['mail'])."'".
				WHERE."ID = 1";
		$query = $this->q($query);
		return $this->h->h3($this->t->w("some values have been modified !"),"class='warning'");
	}
	public function list_pages_select($pageId,$name){
		$query = SELECT.PAGES.".ID,".PAGES.".NAME,".PAGES.".TYPEPAGE".FROM.PAGES;
		$query = $this->q($query);
		$options = array();
		$optionSelectect = null;
		while ( $line = $this->fetch($query) ){
			if ($line['ID'] == $pageId){
				$optionSelectect = "k=".$line['TYPEPAGE']."&amp;v=".$line['ID'];
				$options[$line['NAME']] = "k=".$line['TYPEPAGE']."&amp;v=".$line['ID'];
			} else {
				$options[$line['NAME']] = "k=".$line['TYPEPAGE']."&amp;v=".$line['ID'];
			}
		}
		return $this->h->select($options,$name,$optionSelectect,"onchange='fillHomeFields(this.value)'");
	}
}
?>

==> ulyxex.1.5.0.3.alone.zip: pages/core/admin_site.php <==
<?php
/* Ulyxex version 1.5.0.3 *****************/
class AdminSite extends Admin {
	function __construct(){
		$this->h = New Html();
		$this->t = New Translate();
	}
	public function site_params(){
		$h = $this->h;$t = $this->t;
		if ($_SESSION['userid'] == 1){
			$query = 	SELECT.
							PARAMS.".*,".PAGES.".NAME".
						FROM.
							PARAMS.
							INNERJOIN.PAGES._ON_.PAGES.".ID = ".PARAMS.".PAGEID";
						WHERE.
							PARAMS.".ID = 1"._AND_.PAGES.".ID = ".PARAMS.".PAGEID";
			$query = $this->q($query);
			$dat = $this->fetch($query);
			$_[] = $h->input("hidden","update",1);
			$_[] = $h->p($t->wr("page name in use for home is").$h->b("\"".$dat['NAME']."\""));
			$options = array("tree"=>"tree","line"=>"line","child"=>"child");
			$_[] = $h->p($t->wr("navigation").$h->select($options,"navtype",$dat['NAVTYPE']));
			$_[] = $h->p($t->wr("select home page").$this->list_pages_select($dat['PAGEID'],"pageId"));
			$_[] = $h->p($t->wr("type").$h->input("text","type",$dat['TYPEPAGE'],"readonly='readonly' style='border:none;font-weight:bold'")." &#38;(".$t->w("param").") ".$h->input("text","param",$dat['PAGEID'],"readonly='readonly' style='border:none;font-weight:bold'"));
			$_[] = $h->p($t->wr("main css").$h->input("text","css",$dat['CSS'],"size='50'"));
			$_[] = $h->p($t->wr("articles by page").$h->input("text","articlespage",$dat['ARTICLESPAGE'],"size='4'"));
			$_[] = $h->p("------------------");
			$_[] = $h->p($t->wr("items by page admin").$h->input("text","items",$dat['ITEMS'],"size='4'"));
			$_[] = $h->p($t->wr("website administrator mail").$h->input("text","mail",$dat['MAIL']));
			$_[] = $h->p($h->input("submit","save",$t->w("update all")));
			$inputs = implode("",$_);
			return $h->form($inputs,"home","post","admin.php?action=admin_home");
		}
	}
	public function update_site_params(){
		$vals = explode("&",$_POST['pageId']);
		$typePage = explode("=",$vals[0]);
		$typePage = $typePage[1];
		$paramId = explode("=",$vals[1]);
		$paramId = $paramId[1];
		$query = UPDATE.PARAMS.
					SET."PAGEID = '".$this->h->word($paramId).
					"',TYPEPAGE = '".$this->h->word($typePage).
					"',NAVTYPE = '".$this->h->word($_POST['navtype']).
					"',CSS = '".$this->h->word($_POST['css']).
					"',ARTICLESPAGE = '".$this->h->num($_POST['articlespage']).
					"',ITEMS = '".$this->h->num($_POST['items']).
					"',MAIL = '".$this->h->safe($_POST['mail'])."'".
				WHERE."ID = 1";
		$query = $this->q($query);
		return $this->h->h3($this->t->w("some values have been modified !"),"class='warning'");
	}
	public function list_pages_select($pageId,$name){
		$query = SELECT.PAGES.".ID,".PAGES.".NAME,".PAGES.".TYPEPAGE".FROM.PAGES;
		$query = $this->q($query);
		$options = array();
		$optionSelectect = null;
		while ( $line = $this->fetch($query) ){
			if ($line['ID'] == $pageId){
				$optionSelectect = "k=".$line['TYPEPAGE']."&amp;v=".$line['ID'];
				$options[$line['NAME']] = "k=".$line['TYPEPAGE']."&amp;v=".$line['ID'];
			} else {
				$options[$line['NAME']] = "k=".$line['TYPEPAGE']."&amp;v=".$line['ID'];
			}
		}
		return $this->h->select($options,$name,$optionSelectect,"onchange='fillHomeFields(this.value)'");
	}
}
?>
